function [OUT]=dct1d(A);
% SYNTAX: function [OUT]=dct1d(A);
%
% DESCRIPTION: DCT1D is the Dicrete Cosine Transform
% It is calculated using the fact that the DCT is identical
% to the Fourier Transform of the symetrized sequence, up to
% a phase factor, which corresponds the effective index of symetry.
% If A is a matrix, the output OUT is the dct of each column.
%
% SEE ALSO: idct1d, dc2d, idct2d, fft, ...
%
% Author: JFB (bercherj@esiee.fr) - Nov. 2011 / Jan 1999

[M N]=size(A);
if M*N==length(A)						% A is a vector
	if M==1, A=A';  M=length(A); N=1; end;
end;
OUT=[];
for u=1:N
   x=A(:,u);
	L=length(x);
   xx=[x(1:L) ; flipud(x)];							% (1) symetrization
   out=1/((2)*N)*fft(xx).*exp(-j*2*pi*[0:2*L-1]'/(4*L)); 	%(2) compensation of phase factor
   out(1)=out(1)/sqrt(2);
	OUT=[OUT real(out(1:L))];
end;
