function [Bin]=dec2bin(dec,pmax);
% SYNTAX: [bin]=dec2bin(dec,pmax);
%
% DESCRIPTION: Converts the decimal matrix dec into its
% binary representation bin, using pmax bits
% pmax is optional (pmax=16 by default). 
% If pmax is not specified, the shortest respresentation 
% is returned. 
% If dec is negative, the binary one complement is returned
%
% SEE ALSO: bin2dec
%
% AUTHOR: JFB (october 2011)


if nargin==1
	pmax=16;
end;


[M,N]=size(dec);

Bin=[];
for m=1:M
for n=1:N
	bin=[]; R=dec(m,n);
	neg=0;
	if R<0
		neg=1;
		R=-R;
	end;
    msb_found=0;
    I=(floor(R/2^(pmax-1)));
    if I>1 error(['The specified (or default) number of bits pmax=' num2str(pmax) ' is not sufficient for representing ' num2str(dec(m,n)) ]); end
	for p=pmax-1:-1:0
		I=(floor(R/2^p));
		R=R-2^p*I;
        msb_found=msb_found|I;
        if msb_found
		bin=[bin I];
        end
	end;
    if neg
    	bin=~bin;	% binary one complement
    end	
    vmax=length(bin);
    if nargin==2
        bin=[zeros(1,pmax-vmax) bin];
        vmax=pmax;
    end;    
	Bin(m,(n-1)*vmax+1:n*vmax)=bin;
end;
end;

