function [OUT]=idct1d(A);
% SYNTAX: function [OUT]=idct1d(A);
%
% DESCRIPTION: IDCT1D is the Inverse Dicrete Cosine Transform
% The inverse DCT is computed using the fact that the dct is obtained 
% as a special  Fourier transform.
% If A is a matrix, the output OUT is the idct of each column. 
% SEE ALSO: dct1d, dc2d, idct2d, fft, ...
%
% Author: JFB (bercherj@esiee.fr) - Nov. 2011 / Jan. 1999

[M N]=size(A);
if M*N==length(A)						% A is a vector
	x=A(:); M=length(A); N=1;
end;
OUT=[];
for u=1:N
   x=A(:,u);
   L=length(x);
   x=x.*exp(j*2*pi*[0:L-1]'/(4*L)); % (1) Phase correction
   x(1)=x(1)*sqrt(2);
	x_f=conj(flipud(x));
	xxf=[x(1:L) ; 0 ;  x_f(1:L-1)];	% (2) symetrization
	out= 2*N*ifft(xxf);
	OUT=[OUT real(out(1:L))];
end;